// This is auto-gen data for Capstone engine (www.capstone-engine.org)
// By Nguyen Anh Quynh <aquynh@gmail.com>

{
	SystemZ_A, SYSZ_INS_A,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ADB, SYSZ_INS_ADB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ADBR, SYSZ_INS_ADBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AEB, SYSZ_INS_AEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AEBR, SYSZ_INS_AEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AFI, SYSZ_INS_AFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AG, SYSZ_INS_AG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGF, SYSZ_INS_AGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGFI, SYSZ_INS_AGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGFR, SYSZ_INS_AGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGHI, SYSZ_INS_AGHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGHIK, SYSZ_INS_AGHIK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_AGR, SYSZ_INS_AGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGRK, SYSZ_INS_AGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_AGSI, SYSZ_INS_AGSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AH, SYSZ_INS_AH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AHI, SYSZ_INS_AHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AHIK, SYSZ_INS_AHIK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_AHY, SYSZ_INS_AHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AIH, SYSZ_INS_AIH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_AL, SYSZ_INS_AL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALC, SYSZ_INS_ALC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALCG, SYSZ_INS_ALCG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALCGR, SYSZ_INS_ALCGR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALCR, SYSZ_INS_ALCR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALFI, SYSZ_INS_ALFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALG, SYSZ_INS_ALG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALGF, SYSZ_INS_ALGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALGFI, SYSZ_INS_ALGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALGFR, SYSZ_INS_ALGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALGHSIK, SYSZ_INS_ALGHSIK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_ALGR, SYSZ_INS_ALGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALGRK, SYSZ_INS_ALGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_ALHSIK, SYSZ_INS_ALHSIK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_ALR, SYSZ_INS_ALR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALRK, SYSZ_INS_ALRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_ALY, SYSZ_INS_ALY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AR, SYSZ_INS_AR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ARK, SYSZ_INS_ARK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_ASI, SYSZ_INS_ASI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AXBR, SYSZ_INS_AXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AY, SYSZ_INS_AY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmBCR, SYSZ_INS_BCR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_AsmBRC, SYSZ_INS_BRC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_AsmBRCL, SYSZ_INS_BRCL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_AsmCGIJ, SYSZ_INS_CGIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_AsmCGRJ, SYSZ_INS_CGRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_AsmCIJ, SYSZ_INS_CIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_AsmCLGIJ, SYSZ_INS_CLGIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_AsmCLGRJ, SYSZ_INS_CLGRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_AsmCLIJ, SYSZ_INS_CLIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_AsmCLRJ, SYSZ_INS_CLRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_AsmCRJ, SYSZ_INS_CRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_AsmEBR, SYSZ_INS_BER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmEJ, SYSZ_INS_JE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmEJG, SYSZ_INS_JGE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmELOC, SYSZ_INS_LOCE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmELOCG, SYSZ_INS_LOCGE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmELOCGR, SYSZ_INS_LOCGRE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmELOCR, SYSZ_INS_LOCRE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmESTOC, SYSZ_INS_STOCE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmESTOCG, SYSZ_INS_STOCGE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHBR, SYSZ_INS_BHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHEBR, SYSZ_INS_BHER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHEJ, SYSZ_INS_JHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHEJG, SYSZ_INS_JGHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHELOC, SYSZ_INS_LOCHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHELOCG, SYSZ_INS_LOCGHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHELOCGR, SYSZ_INS_LOCGRHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHELOCR, SYSZ_INS_LOCRHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHESTOC, SYSZ_INS_STOCHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHESTOCG, SYSZ_INS_STOCGHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHJ, SYSZ_INS_JH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHJG, SYSZ_INS_JGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHLOC, SYSZ_INS_LOCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHLOCG, SYSZ_INS_LOCGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHLOCGR, SYSZ_INS_LOCGRH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHLOCR, SYSZ_INS_LOCRH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHSTOC, SYSZ_INS_STOCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmHSTOCG, SYSZ_INS_STOCGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJEAltCGI, SYSZ_INS_CGIJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJEAltCGR, SYSZ_INS_CGRJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJEAltCI, SYSZ_INS_CIJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJEAltCLGI, SYSZ_INS_CLGIJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJEAltCLGR, SYSZ_INS_CLGRJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJEAltCLI, SYSZ_INS_CLIJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJEAltCLR, SYSZ_INS_CLRJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJEAltCR, SYSZ_INS_CRJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJECGI, SYSZ_INS_CGIJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJECGR, SYSZ_INS_CGRJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJECI, SYSZ_INS_CIJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJECLGI, SYSZ_INS_CLGIJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJECLGR, SYSZ_INS_CLGRJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJECLI, SYSZ_INS_CLIJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJECLR, SYSZ_INS_CLRJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJECR, SYSZ_INS_CRJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHAltCGI, SYSZ_INS_CGIJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHAltCGR, SYSZ_INS_CGRJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHAltCI, SYSZ_INS_CIJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHAltCLGI, SYSZ_INS_CLGIJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHAltCLGR, SYSZ_INS_CLGRJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHAltCLI, SYSZ_INS_CLIJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHAltCLR, SYSZ_INS_CLRJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHAltCR, SYSZ_INS_CRJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHCGI, SYSZ_INS_CGIJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHCGR, SYSZ_INS_CGRJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHCI, SYSZ_INS_CIJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHCLGI, SYSZ_INS_CLGIJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHCLGR, SYSZ_INS_CLGRJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHCLI, SYSZ_INS_CLIJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHCLR, SYSZ_INS_CLRJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHCR, SYSZ_INS_CRJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHEAltCGI, SYSZ_INS_CGIJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHEAltCGR, SYSZ_INS_CGRJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHEAltCI, SYSZ_INS_CIJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHEAltCLGI, SYSZ_INS_CLGIJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHEAltCLGR, SYSZ_INS_CLGRJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHEAltCLI, SYSZ_INS_CLIJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHEAltCLR, SYSZ_INS_CLRJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHEAltCR, SYSZ_INS_CRJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHECGI, SYSZ_INS_CGIJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHECGR, SYSZ_INS_CGRJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHECI, SYSZ_INS_CIJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHECLGI, SYSZ_INS_CLGIJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHECLGR, SYSZ_INS_CLGRJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHECLI, SYSZ_INS_CLIJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHECLR, SYSZ_INS_CLRJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJHECR, SYSZ_INS_CRJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLAltCGI, SYSZ_INS_CGIJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLAltCGR, SYSZ_INS_CGRJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLAltCI, SYSZ_INS_CIJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLAltCLGI, SYSZ_INS_CLGIJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLAltCLGR, SYSZ_INS_CLGRJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLAltCLI, SYSZ_INS_CLIJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLAltCLR, SYSZ_INS_CLRJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLAltCR, SYSZ_INS_CRJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLCGI, SYSZ_INS_CGIJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLCGR, SYSZ_INS_CGRJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLCI, SYSZ_INS_CIJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLCLGI, SYSZ_INS_CLGIJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLCLGR, SYSZ_INS_CLGRJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLCLI, SYSZ_INS_CLIJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLCLR, SYSZ_INS_CLRJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLCR, SYSZ_INS_CRJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLEAltCGI, SYSZ_INS_CGIJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLEAltCGR, SYSZ_INS_CGRJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLEAltCI, SYSZ_INS_CIJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLEAltCLGI, SYSZ_INS_CLGIJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLEAltCLGR, SYSZ_INS_CLGRJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLEAltCLI, SYSZ_INS_CLIJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLEAltCLR, SYSZ_INS_CLRJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLEAltCR, SYSZ_INS_CRJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLECGI, SYSZ_INS_CGIJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLECGR, SYSZ_INS_CGRJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLECI, SYSZ_INS_CIJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLECLGI, SYSZ_INS_CLGIJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLECLGR, SYSZ_INS_CLGRJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLECLI, SYSZ_INS_CLIJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLECLR, SYSZ_INS_CLRJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLECR, SYSZ_INS_CRJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHAltCGI, SYSZ_INS_CGIJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHAltCGR, SYSZ_INS_CGRJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHAltCI, SYSZ_INS_CIJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHAltCLGI, SYSZ_INS_CLGIJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHAltCLGR, SYSZ_INS_CLGRJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHAltCLI, SYSZ_INS_CLIJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHAltCLR, SYSZ_INS_CLRJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHAltCR, SYSZ_INS_CRJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHCGI, SYSZ_INS_CGIJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHCGR, SYSZ_INS_CGRJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHCI, SYSZ_INS_CIJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHCLGI, SYSZ_INS_CLGIJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHCLGR, SYSZ_INS_CLGRJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHCLI, SYSZ_INS_CLIJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHCLR, SYSZ_INS_CLRJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmJLHCR, SYSZ_INS_CRJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLBR, SYSZ_INS_BLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLEBR, SYSZ_INS_BLER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLEJ, SYSZ_INS_JLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLEJG, SYSZ_INS_JGLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLELOC, SYSZ_INS_LOCLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLELOCG, SYSZ_INS_LOCGLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLELOCGR, SYSZ_INS_LOCGRLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLELOCR, SYSZ_INS_LOCRLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLESTOC, SYSZ_INS_STOCLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLESTOCG, SYSZ_INS_STOCGLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLHBR, SYSZ_INS_BLHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLHJ, SYSZ_INS_JLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLHJG, SYSZ_INS_JGLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLHLOC, SYSZ_INS_LOCLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLHLOCG, SYSZ_INS_LOCGLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLHLOCGR, SYSZ_INS_LOCGRLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLHLOCR, SYSZ_INS_LOCRLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLHSTOC, SYSZ_INS_STOCLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLHSTOCG, SYSZ_INS_STOCGLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLJ, SYSZ_INS_JL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLJG, SYSZ_INS_JGL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLLOC, SYSZ_INS_LOCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLLOCG, SYSZ_INS_LOCGL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLLOCGR, SYSZ_INS_LOCGRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLLOCR, SYSZ_INS_LOCRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLOC, SYSZ_INS_LOC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLOCG, SYSZ_INS_LOCG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLOCGR, SYSZ_INS_LOCGR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLOCR, SYSZ_INS_LOCR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLSTOC, SYSZ_INS_STOCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmLSTOCG, SYSZ_INS_STOCGL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNEBR, SYSZ_INS_BNER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNEJ, SYSZ_INS_JNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNEJG, SYSZ_INS_JGNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNELOC, SYSZ_INS_LOCNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNELOCG, SYSZ_INS_LOCGNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNELOCGR, SYSZ_INS_LOCGRNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNELOCR, SYSZ_INS_LOCRNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNESTOC, SYSZ_INS_STOCNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNESTOCG, SYSZ_INS_STOCGNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHBR, SYSZ_INS_BNHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHEBR, SYSZ_INS_BNHER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHEJ, SYSZ_INS_JNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHEJG, SYSZ_INS_JGNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHELOC, SYSZ_INS_LOCNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHELOCG, SYSZ_INS_LOCGNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHELOCGR, SYSZ_INS_LOCGRNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHELOCR, SYSZ_INS_LOCRNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHESTOC, SYSZ_INS_STOCNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHESTOCG, SYSZ_INS_STOCGNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHJ, SYSZ_INS_JNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHJG, SYSZ_INS_JGNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHLOC, SYSZ_INS_LOCNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHLOCG, SYSZ_INS_LOCGNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHLOCGR, SYSZ_INS_LOCGRNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHLOCR, SYSZ_INS_LOCRNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHSTOC, SYSZ_INS_STOCNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNHSTOCG, SYSZ_INS_STOCGNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLBR, SYSZ_INS_BNLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLEBR, SYSZ_INS_BNLER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLEJ, SYSZ_INS_JNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLEJG, SYSZ_INS_JGNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLELOC, SYSZ_INS_LOCNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLELOCG, SYSZ_INS_LOCGNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLELOCGR, SYSZ_INS_LOCGRNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLELOCR, SYSZ_INS_LOCRNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLESTOC, SYSZ_INS_STOCNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLESTOCG, SYSZ_INS_STOCGNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLHBR, SYSZ_INS_BNLHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLHJ, SYSZ_INS_JNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLHJG, SYSZ_INS_JGNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLHLOC, SYSZ_INS_LOCNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLHLOCG, SYSZ_INS_LOCGNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLHLOCGR, SYSZ_INS_LOCGRNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLHLOCR, SYSZ_INS_LOCRNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLHSTOC, SYSZ_INS_STOCNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLHSTOCG, SYSZ_INS_STOCGNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLJ, SYSZ_INS_JNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLJG, SYSZ_INS_JGNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLLOC, SYSZ_INS_LOCNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLLOCG, SYSZ_INS_LOCGNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLLOCGR, SYSZ_INS_LOCGRNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLLOCR, SYSZ_INS_LOCRNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLSTOC, SYSZ_INS_STOCNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNLSTOCG, SYSZ_INS_STOCGNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNOBR, SYSZ_INS_BNOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNOJ, SYSZ_INS_JNO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNOJG, SYSZ_INS_JGNO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNOLOC, SYSZ_INS_LOCNO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNOLOCG, SYSZ_INS_LOCGNO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNOLOCGR, SYSZ_INS_LOCGRNO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNOLOCR, SYSZ_INS_LOCRNO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNOSTOC, SYSZ_INS_STOCNO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmNOSTOCG, SYSZ_INS_STOCGNO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmOBR, SYSZ_INS_BOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmOJ, SYSZ_INS_JO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmOJG, SYSZ_INS_JGO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AsmOLOC, SYSZ_INS_LOCO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmOLOCG, SYSZ_INS_LOCGO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmOLOCGR, SYSZ_INS_LOCGRO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmOLOCR, SYSZ_INS_LOCRO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmOSTOC, SYSZ_INS_STOCO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmOSTOCG, SYSZ_INS_STOCGO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmSTOC, SYSZ_INS_STOC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_AsmSTOCG, SYSZ_INS_STOCG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_BASR, SYSZ_INS_BASR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BR, SYSZ_INS_BR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAS, SYSZ_INS_BRAS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BRASL, SYSZ_INS_BRASL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BRC, SYSZ_INS_J,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BRCL, SYSZ_INS_JG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BRCT, SYSZ_INS_BRCT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BRCTG, SYSZ_INS_BRCTG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_C, SYSZ_INS_C,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDB, SYSZ_INS_CDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDBR, SYSZ_INS_CDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDFBR, SYSZ_INS_CDFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDGBR, SYSZ_INS_CDGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDLFBR, SYSZ_INS_CDLFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CDLGBR, SYSZ_INS_CDLGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CEB, SYSZ_INS_CEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CEBR, SYSZ_INS_CEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CEFBR, SYSZ_INS_CEFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CEGBR, SYSZ_INS_CEGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CELFBR, SYSZ_INS_CELFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CELGBR, SYSZ_INS_CELGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CFDBR, SYSZ_INS_CFDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFEBR, SYSZ_INS_CFEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFI, SYSZ_INS_CFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFXBR, SYSZ_INS_CFXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CG, SYSZ_INS_CG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGDBR, SYSZ_INS_CGDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGEBR, SYSZ_INS_CGEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGF, SYSZ_INS_CGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGFI, SYSZ_INS_CGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGFR, SYSZ_INS_CGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGFRL, SYSZ_INS_CGFRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGH, SYSZ_INS_CGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGHI, SYSZ_INS_CGHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGHRL, SYSZ_INS_CGHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGHSI, SYSZ_INS_CGHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGIJ, SYSZ_INS_CGIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGR, SYSZ_INS_CGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRJ, SYSZ_INS_CGRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRL, SYSZ_INS_CGRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGXBR, SYSZ_INS_CGXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CH, SYSZ_INS_CH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CHF, SYSZ_INS_CHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CHHSI, SYSZ_INS_CHHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CHI, SYSZ_INS_CHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CHRL, SYSZ_INS_CHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CHSI, SYSZ_INS_CHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CHY, SYSZ_INS_CHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CIH, SYSZ_INS_CIH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CIJ, SYSZ_INS_CIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CL, SYSZ_INS_CL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLC, SYSZ_INS_CLC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFDBR, SYSZ_INS_CLFDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLFEBR, SYSZ_INS_CLFEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLFHSI, SYSZ_INS_CLFHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFI, SYSZ_INS_CLFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFXBR, SYSZ_INS_CLFXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLG, SYSZ_INS_CLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGDBR, SYSZ_INS_CLGDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGEBR, SYSZ_INS_CLGEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGF, SYSZ_INS_CLGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGFI, SYSZ_INS_CLGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGFR, SYSZ_INS_CLGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGFRL, SYSZ_INS_CLGFRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGHRL, SYSZ_INS_CLGHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGHSI, SYSZ_INS_CLGHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGIJ, SYSZ_INS_CLGIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGR, SYSZ_INS_CLGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRJ, SYSZ_INS_CLGRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRL, SYSZ_INS_CLGRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGXBR, SYSZ_INS_CLGXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLHF, SYSZ_INS_CLHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CLHHSI, SYSZ_INS_CLHHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLHRL, SYSZ_INS_CLHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLI, SYSZ_INS_CLI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLIH, SYSZ_INS_CLIH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CLIJ, SYSZ_INS_CLIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIY, SYSZ_INS_CLIY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLR, SYSZ_INS_CLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRJ, SYSZ_INS_CLRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRL, SYSZ_INS_CLRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLST, SYSZ_INS_CLST,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_R0L, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLY, SYSZ_INS_CLY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CPSDRdd, SYSZ_INS_CPSDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CPSDRds, SYSZ_INS_CPSDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CPSDRsd, SYSZ_INS_CPSDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CPSDRss, SYSZ_INS_CPSDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CR, SYSZ_INS_CR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRJ, SYSZ_INS_CRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRL, SYSZ_INS_CRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CS, SYSZ_INS_CS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CSG, SYSZ_INS_CSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CSY, SYSZ_INS_CSY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXBR, SYSZ_INS_CXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXFBR, SYSZ_INS_CXFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXGBR, SYSZ_INS_CXGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXLFBR, SYSZ_INS_CXLFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CXLGBR, SYSZ_INS_CXLGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CY, SYSZ_INS_CY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DDB, SYSZ_INS_DDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DDBR, SYSZ_INS_DDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DEB, SYSZ_INS_DEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DEBR, SYSZ_INS_DEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DL, SYSZ_INS_DL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DLG, SYSZ_INS_DLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DLGR, SYSZ_INS_DLGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DLR, SYSZ_INS_DLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DSG, SYSZ_INS_DSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DSGF, SYSZ_INS_DSGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DSGFR, SYSZ_INS_DSGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DSGR, SYSZ_INS_DSGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DXBR, SYSZ_INS_DXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EAR, SYSZ_INS_EAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIDBR, SYSZ_INS_FIDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIDBRA, SYSZ_INS_FIDBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_FIEBR, SYSZ_INS_FIEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIEBRA, SYSZ_INS_FIEBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_FIXBR, SYSZ_INS_FIXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIXBRA, SYSZ_INS_FIXBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_FLOGR, SYSZ_INS_FLOGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IC, SYSZ_INS_IC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IC32, SYSZ_INS_IC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IC32Y, SYSZ_INS_ICY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ICY, SYSZ_INS_ICY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IIHF, SYSZ_INS_IIHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IIHH, SYSZ_INS_IIHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IIHL, SYSZ_INS_IIHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IILF, SYSZ_INS_IILF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IILH, SYSZ_INS_IILH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IILL, SYSZ_INS_IILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IPM, SYSZ_INS_IPM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_J, SYSZ_INS_J,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JG, SYSZ_INS_JG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_L, SYSZ_INS_L,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LA, SYSZ_INS_LA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LAA, SYSZ_INS_LAA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAAG, SYSZ_INS_LAAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAAL, SYSZ_INS_LAAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAALG, SYSZ_INS_LAALG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAN, SYSZ_INS_LAN,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LANG, SYSZ_INS_LANG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAO, SYSZ_INS_LAO,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAOG, SYSZ_INS_LAOG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LARL, SYSZ_INS_LARL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LAX, SYSZ_INS_LAX,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAXG, SYSZ_INS_LAXG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAY, SYSZ_INS_LAY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LB, SYSZ_INS_LB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LBH, SYSZ_INS_LBH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_LBR, SYSZ_INS_LBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCDBR, SYSZ_INS_LCDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCEBR, SYSZ_INS_LCEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCGFR, SYSZ_INS_LCGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCGR, SYSZ_INS_LCGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCR, SYSZ_INS_LCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCXBR, SYSZ_INS_LCXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LD, SYSZ_INS_LD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDEB, SYSZ_INS_LDEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDEBR, SYSZ_INS_LDEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDGR, SYSZ_INS_LDGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDR, SYSZ_INS_LDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDXBR, SYSZ_INS_LDXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDXBRA, SYSZ_INS_LDXBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_LDY, SYSZ_INS_LDY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LE, SYSZ_INS_LE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LEDBR, SYSZ_INS_LEDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LEDBRA, SYSZ_INS_LEDBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_LER, SYSZ_INS_LER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LEXBR, SYSZ_INS_LEXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LEXBRA, SYSZ_INS_LEXBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_LEY, SYSZ_INS_LEY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LFH, SYSZ_INS_LFH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_LG, SYSZ_INS_LG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGB, SYSZ_INS_LGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGBR, SYSZ_INS_LGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGDR, SYSZ_INS_LGDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGF, SYSZ_INS_LGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGFI, SYSZ_INS_LGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGFR, SYSZ_INS_LGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGFRL, SYSZ_INS_LGFRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGH, SYSZ_INS_LGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGHI, SYSZ_INS_LGHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGHR, SYSZ_INS_LGHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGHRL, SYSZ_INS_LGHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGR, SYSZ_INS_LGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGRL, SYSZ_INS_LGRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LH, SYSZ_INS_LH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LHH, SYSZ_INS_LHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_LHI, SYSZ_INS_LHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LHR, SYSZ_INS_LHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LHRL, SYSZ_INS_LHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LHY, SYSZ_INS_LHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLC, SYSZ_INS_LLC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLCH, SYSZ_INS_LLCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_LLCR, SYSZ_INS_LLCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGC, SYSZ_INS_LLGC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGCR, SYSZ_INS_LLGCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGF, SYSZ_INS_LLGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGFR, SYSZ_INS_LLGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGFRL, SYSZ_INS_LLGFRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGH, SYSZ_INS_LLGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGHR, SYSZ_INS_LLGHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGHRL, SYSZ_INS_LLGHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLH, SYSZ_INS_LLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLHH, SYSZ_INS_LLHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_LLHR, SYSZ_INS_LLHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLHRL, SYSZ_INS_LLHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLIHF, SYSZ_INS_LLIHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLIHH, SYSZ_INS_LLIHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLIHL, SYSZ_INS_LLIHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLILF, SYSZ_INS_LLILF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLILH, SYSZ_INS_LLILH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLILL, SYSZ_INS_LLILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LMG, SYSZ_INS_LMG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNDBR, SYSZ_INS_LNDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNEBR, SYSZ_INS_LNEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNGFR, SYSZ_INS_LNGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNGR, SYSZ_INS_LNGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNR, SYSZ_INS_LNR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNXBR, SYSZ_INS_LNXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LOC, SYSZ_INS_LOC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCG, SYSZ_INS_LOCG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGR, SYSZ_INS_LOCGR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCR, SYSZ_INS_LOCR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LPDBR, SYSZ_INS_LPDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPEBR, SYSZ_INS_LPEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPGFR, SYSZ_INS_LPGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPGR, SYSZ_INS_LPGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPR, SYSZ_INS_LPR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPXBR, SYSZ_INS_LPXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LR, SYSZ_INS_LR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRL, SYSZ_INS_LRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRV, SYSZ_INS_LRV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRVG, SYSZ_INS_LRVG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRVGR, SYSZ_INS_LRVGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRVR, SYSZ_INS_LRVR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LT, SYSZ_INS_LT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTDBR, SYSZ_INS_LTDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTDBRCompare, SYSZ_INS_LTDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTEBR, SYSZ_INS_LTEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTEBRCompare, SYSZ_INS_LTEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTG, SYSZ_INS_LTG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTGF, SYSZ_INS_LTGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTGFR, SYSZ_INS_LTGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTGR, SYSZ_INS_LTGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTR, SYSZ_INS_LTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTXBR, SYSZ_INS_LTXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTXBRCompare, SYSZ_INS_LTXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXDB, SYSZ_INS_LXDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXDBR, SYSZ_INS_LXDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXEB, SYSZ_INS_LXEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXEBR, SYSZ_INS_LXEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXR, SYSZ_INS_LXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LY, SYSZ_INS_LY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LZDR, SYSZ_INS_LZDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LZER, SYSZ_INS_LZER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LZXR, SYSZ_INS_LZXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MADB, SYSZ_INS_MADB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MADBR, SYSZ_INS_MADBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAEB, SYSZ_INS_MAEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAEBR, SYSZ_INS_MAEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDB, SYSZ_INS_MDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDBR, SYSZ_INS_MDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDEB, SYSZ_INS_MDEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDEBR, SYSZ_INS_MDEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MEEB, SYSZ_INS_MEEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MEEBR, SYSZ_INS_MEEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MGHI, SYSZ_INS_MGHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MH, SYSZ_INS_MH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MHI, SYSZ_INS_MHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MHY, SYSZ_INS_MHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MLG, SYSZ_INS_MLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MLGR, SYSZ_INS_MLGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MS, SYSZ_INS_MS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSDB, SYSZ_INS_MSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSDBR, SYSZ_INS_MSDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSEB, SYSZ_INS_MSEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSEBR, SYSZ_INS_MSEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSFI, SYSZ_INS_MSFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSG, SYSZ_INS_MSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSGF, SYSZ_INS_MSGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSGFI, SYSZ_INS_MSGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSGFR, SYSZ_INS_MSGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSGR, SYSZ_INS_MSGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSR, SYSZ_INS_MSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSY, SYSZ_INS_MSY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVC, SYSZ_INS_MVC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVGHI, SYSZ_INS_MVGHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVHHI, SYSZ_INS_MVHHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVHI, SYSZ_INS_MVHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVI, SYSZ_INS_MVI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVIY, SYSZ_INS_MVIY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVST, SYSZ_INS_MVST,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_R0L, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MXBR, SYSZ_INS_MXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MXDB, SYSZ_INS_MXDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MXDBR, SYSZ_INS_MXDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_N, SYSZ_INS_N,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NC, SYSZ_INS_NC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NG, SYSZ_INS_NG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NGR, SYSZ_INS_NGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NGRK, SYSZ_INS_NGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_NI, SYSZ_INS_NI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NIHF, SYSZ_INS_NIHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NIHH, SYSZ_INS_NIHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NIHL, SYSZ_INS_NIHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NILF, SYSZ_INS_NILF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NILH, SYSZ_INS_NILH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NILL, SYSZ_INS_NILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NIY, SYSZ_INS_NIY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NR, SYSZ_INS_NR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NRK, SYSZ_INS_NRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_NY, SYSZ_INS_NY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_O, SYSZ_INS_O,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OC, SYSZ_INS_OC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OG, SYSZ_INS_OG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OGR, SYSZ_INS_OGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OGRK, SYSZ_INS_OGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_OI, SYSZ_INS_OI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OIHF, SYSZ_INS_OIHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OIHH, SYSZ_INS_OIHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OIHL, SYSZ_INS_OIHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OILF, SYSZ_INS_OILF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OILH, SYSZ_INS_OILH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OILL, SYSZ_INS_OILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OIY, SYSZ_INS_OIY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OR, SYSZ_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ORK, SYSZ_INS_ORK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_OY, SYSZ_INS_OY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PFD, SYSZ_INS_PFD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PFDRL, SYSZ_INS_PFDRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RISBG, SYSZ_INS_RISBG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RISBG32, SYSZ_INS_RISBG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RISBHG, SYSZ_INS_RISBHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_RISBLG, SYSZ_INS_RISBLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_RLL, SYSZ_INS_RLL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RLLG, SYSZ_INS_RLLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RNSBG, SYSZ_INS_RNSBG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ROSBG, SYSZ_INS_ROSBG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RXSBG, SYSZ_INS_RXSBG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_S, SYSZ_INS_S,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SDB, SYSZ_INS_SDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SDBR, SYSZ_INS_SDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SEB, SYSZ_INS_SEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SEBR, SYSZ_INS_SEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SG, SYSZ_INS_SG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SGF, SYSZ_INS_SGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SGFR, SYSZ_INS_SGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SGR, SYSZ_INS_SGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SGRK, SYSZ_INS_SGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SH, SYSZ_INS_SH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SHY, SYSZ_INS_SHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SL, SYSZ_INS_SL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLB, SYSZ_INS_SLB,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLBG, SYSZ_INS_SLBG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLBR, SYSZ_INS_SLBR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLFI, SYSZ_INS_SLFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLG, SYSZ_INS_SLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLGBR, SYSZ_INS_SLBGR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLGF, SYSZ_INS_SLGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLGFI, SYSZ_INS_SLGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLGFR, SYSZ_INS_SLGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLGR, SYSZ_INS_SLGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLGRK, SYSZ_INS_SLGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SLL, SYSZ_INS_SLL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLLG, SYSZ_INS_SLLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLLK, SYSZ_INS_SLLK,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SLR, SYSZ_INS_SLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLRK, SYSZ_INS_SLRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SLY, SYSZ_INS_SLY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQDB, SYSZ_INS_SQDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQDBR, SYSZ_INS_SQDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQEB, SYSZ_INS_SQEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQEBR, SYSZ_INS_SQEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQXBR, SYSZ_INS_SQXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SR, SYSZ_INS_SR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRA, SYSZ_INS_SRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRAG, SYSZ_INS_SRAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRAK, SYSZ_INS_SRAK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SRK, SYSZ_INS_SRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SRL, SYSZ_INS_SRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRLG, SYSZ_INS_SRLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRLK, SYSZ_INS_SRLK,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SRST, SYSZ_INS_SRST,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_R0L, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ST, SYSZ_INS_ST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STC, SYSZ_INS_STC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCH, SYSZ_INS_STCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_STCY, SYSZ_INS_STCY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STD, SYSZ_INS_STD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STDY, SYSZ_INS_STDY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STE, SYSZ_INS_STE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STEY, SYSZ_INS_STEY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STFH, SYSZ_INS_STFH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_STG, SYSZ_INS_STG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STGRL, SYSZ_INS_STGRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STH, SYSZ_INS_STH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STHH, SYSZ_INS_STHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_STHRL, SYSZ_INS_STHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STHY, SYSZ_INS_STHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STMG, SYSZ_INS_STMG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STOC, SYSZ_INS_STOC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCG, SYSZ_INS_STOCG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STRL, SYSZ_INS_STRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STRV, SYSZ_INS_STRV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STRVG, SYSZ_INS_STRVG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STY, SYSZ_INS_STY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SXBR, SYSZ_INS_SXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SY, SYSZ_INS_SY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TM, SYSZ_INS_TM,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TMHH, SYSZ_INS_TMHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TMHL, SYSZ_INS_TMHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TMLH, SYSZ_INS_TMLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TMLL, SYSZ_INS_TMLL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TMY, SYSZ_INS_TMY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_X, SYSZ_INS_X,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XC, SYSZ_INS_XC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XG, SYSZ_INS_XG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XGR, SYSZ_INS_XGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XGRK, SYSZ_INS_XGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_XI, SYSZ_INS_XI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XIHF, SYSZ_INS_XIHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XILF, SYSZ_INS_XILF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XIY, SYSZ_INS_XIY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XR, SYSZ_INS_XR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XRK, SYSZ_INS_XRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_XY, SYSZ_INS_XY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
